@@ -1,4 +1,6 @@
-/* GDM - The GNOME Display Manager
+/* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*-
+ *
+ * GDM - The GNOME Display Manager
  * Copyright (C) 1998, 1999, 2000 Martin K. Petersen <mkp@mkp.net>
  *
  * This program is free software; you can redistribute it and/or modify
@@ -19,27 +21,11 @@
 #ifndef GDM_XDMCP_H
 #define GDM_XDMCP_H
 
-#ifdef HAVE_LIBXDMCP
-#include <glib.h>
-#include <X11/Xlib.h>
-#include <X11/Xmd.h>
-#include <X11/Xauth.h>
-#include <X11/Xdmcp.h>
-#include "gdm.h"
-#endif /* HAVE_LIBXDMCP */
-
 /* Note that these are defined as empty stubs if there is no XDMCP support */
 gboolean	gdm_xdmcp_init	(void);
 void		gdm_xdmcp_run	(void);
 void		gdm_xdmcp_close	(void);
 
-void gdm_xdmcp_migrate (GdmDisplay *from, GdmDisplay *to);
-
-#ifdef HAVE_LIBXDMCP
-/* Fix broken X includes */
-int XdmcpReallocARRAY8 (ARRAY8Ptr array, int length);
-#endif /* HAVE_LIBXDMCP */
+void            gdm_xdmcp_migrate (GdmDisplay *from, GdmDisplay *to);
 
 #endif /* GDM_XDMCP_H */
-
-/* EOF */
